Struct pnet::datalink::dummy::Config
[−]
[src]
pub struct Config {
// some fields omitted
}Configuration for the dummy datalink backend. Contains std::sync::mpsc
channels that are used to communicate with the fake network.
Methods
impl Config[src]
fn new(receiver: Receiver<Result<Box<[u8]>>>, sender: Sender<Box<[u8]>>) -> Config
Creates a new Config with the given channels as the backing network.
When using this constructor inject_handle and read_handle will return None.
Those handles must be kept track of elsewhere.
The EthernetDataLinkChannelIterator created by the dummy backend will read packets from
receiver. Both network errors and data can be sent on this channel.
When the receiver channel is closed (Sender is dropped)
EthernetDataLinkChannelIterator::next() will sleep forever, simlating an idle network.
The EthernetDataLinkSender created by the dummy backend will send all packets sent
through build_and_send() and send_to() to the sender channel.
fn inject_handle(&mut self) -> Option<Sender<Result<Box<[u8]>>>>
Get the Sender handle that can inject packets in the fake network.
Only usable with Configs generated from default()
fn read_handle(&mut self) -> Option<Receiver<Box<[u8]>>>
Get the Receiver handle where packets sent to the fake network can be read.
Only usable with Configs generated from default()