Struct pnet::datalink::linux::Config
[−]
[src]
pub struct Config {
pub write_buffer_size: usize,
pub read_buffer_size: usize,
pub read_timeout: Option<Duration>,
pub write_timeout: Option<Duration>,
pub channel_type: ChannelType,
}Configuration for the Linux datalink backend
Fields
write_buffer_size | The size of buffer to use when writing packets. Defaults to 4096 |
read_buffer_size | The size of buffer to use when reading packets. Defaults to 4096 |
read_timeout | The read timeout. Defaults to None. |
write_timeout | The write timeout. Defaults to None. |
channel_type | Specifies whether to read packets at the datalink layer or network layer. NOTE FIXME Currently ignored Defaults to Layer2 |