Trait pnet::datalink::EthernetDataLinkReceiver
[−]
[src]
pub trait EthernetDataLinkReceiver: Send {
fn iter<'a>(&'a mut self) -> Box<EthernetDataLinkChannelIterator + 'a>;
}Structure for receiving packets at the data link layer. Should be constructed using datalink_channel().
Required Methods
fn iter<'a>(&'a mut self) -> Box<EthernetDataLinkChannelIterator + 'a>
Returns an iterator over EthernetPackets.
This will likely be removed once other layer two types are supported.