[−][src]Struct pnet::packet::tcp::MutableTcpOptionPacket
A structure enabling manipulation of on the wire packets
Methods
impl<'a> MutableTcpOptionPacket<'a>[src]
pub fn new(packet: &'p mut [u8]) -> Option<MutableTcpOptionPacket<'p>>[src]
Constructs a new MutableTcpOptionPacket. If the provided buffer is less than the minimum required packet size, this will return None.
pub fn owned(packet: Vec<u8>) -> Option<MutableTcpOptionPacket<'static>>[src]
Constructs a new MutableTcpOptionPacket. If the provided buffer is less than the minimum required packet size, this will return None. With this constructor the MutableTcpOptionPacket will own its own data and the underlying buffer will be dropped when the MutableTcpOptionPacket is.
pub fn to_immutable(&'p self) -> TcpOptionPacket<'p>[src]
Maps from a MutableTcpOptionPacket to a TcpOptionPacket
pub fn consume_to_immutable(self) -> TcpOptionPacket<'a>[src]
Maps from a MutableTcpOptionPacket to a TcpOptionPacket while consuming the source
pub fn minimum_packet_size() -> usize[src]
The minimum size (in bytes) a packet of this type can be. It's based on the total size of the fixed-size fields.
pub fn packet_size(_packet: &TcpOption) -> usize[src]
The size (in bytes) of a TcpOption instance when converted into a byte-array
pub fn populate(&mut self, packet: &TcpOption)[src]
Populates a TcpOptionPacket using a TcpOption structure
pub fn get_number(&self) -> TcpOptionNumber[src]
Get the value of the number field
pub fn get_length_raw(&self) -> &[u8][src]
Get the raw &u8 value of the length field, without copying
pub fn get_length(&self) -> Vec<u8>[src]
Get the value of the length field (copies contents)
pub fn set_number(&mut self, val: TcpOptionNumber)[src]
Set the value of the number field
pub fn get_length_raw_mut(&mut self) -> &mut [u8][src]
Get the raw &mut u8 value of the length field, without copying
pub fn set_length(&mut self, vals: &[u8])[src]
Set the value of the length field (copies contents)
pub fn set_data(&mut self, vals: &[u8])[src]
Set the value of the data field (copies contents)