Enum pnet::util::ParseMacAddrErr
[−]
[src]
pub enum ParseMacAddrErr {
TooManyComponents,
TooFewComponents,
InvalidComponent,
}Represents an error which occurred whilst parsing a MAC address
Variants
TooManyComponents | The MAC address has too many components, eg. 00:11:22:33:44:55:66 | |
TooFewComponents | The MAC address has too few components, eg. 00:11 | |
InvalidComponent | One of the components contains an invalid value, eg. 00:GG:22:33:44:55 |