[−][src]Module pnet::packet
Support for packet parsing and manipulation
Modules
| arp | ARP packet abstraction |
| ethernet | Ethernet packet abstraction |
| gre | Minimal GRE Packet implementation: suitable for inspection not generation (e.g. checksum not implemented). |
| icmp | ICMP packet abstraction |
| icmpv6 | ICMPv6 packet abstraction |
| ip | Defines the type and constants for IP next header/next level protocol fields. |
| ipv4 | IPv4 packet abstraction |
| ipv6 | IPv6 packet abstraction |
| tcp | TCP packet abstraction |
| udp | UDP packet abstraction |
| util | Utilities for working with packets, eg. checksumming |
| vlan | VLAN packet abstraction |
Enums
| MutPacketData | Mutable packet data |
| PacketData | Packet data |
Traits
| FromPacket | Used to convert on-the-wire packets to their #[packet] equivalent |
| MutablePacket | Represents a generic, mutable, network packet |
| Packet | Represents a generic network packet |
| PacketSize | Used to find the calculated size of the packet. This is used for occasions where the underlying buffer is not the same length as the packet itself. |
| PrimitiveValues | Used to convert a type to primitive values representing it |