[−][src]Struct pnet::packet::icmp::echo_reply::EchoReplyPacket
A structure enabling manipulation of on the wire packets
Methods
impl<'a> EchoReplyPacket<'a>[src]
pub fn new(packet: &'p [u8]) -> Option<EchoReplyPacket<'p>>[src]
Constructs a new EchoReplyPacket. If the provided buffer is less than the minimum required packet size, this will return None.
pub fn owned(packet: Vec<u8>) -> Option<EchoReplyPacket<'static>>[src]
Constructs a new EchoReplyPacket. If the provided buffer is less than the minimum required packet size, this will return None. With this constructor the EchoReplyPacket will own its own data and the underlying buffer will be dropped when the EchoReplyPacket is.
pub fn to_immutable(&'p self) -> EchoReplyPacket<'p>[src]
Maps from a EchoReplyPacket to a EchoReplyPacket
pub fn consume_to_immutable(self) -> EchoReplyPacket<'a>[src]
Maps from a EchoReplyPacket to a EchoReplyPacket while consuming the source
pub fn minimum_packet_size() -> usize[src]
The minimum size (in bytes) a packet of this type can be. It's based on the total size of the fixed-size fields.
pub fn packet_size(_packet: &EchoReply) -> usize[src]
The size (in bytes) of a EchoReply instance when converted into a byte-array
pub fn get_icmp_type(&self) -> IcmpType[src]
Get the value of the icmp_type field
pub fn get_icmp_code(&self) -> IcmpCode[src]
Get the value of the icmp_code field
pub fn get_checksum(&self) -> u16[src]
Get the checksum field. This field is always stored big-endian within the struct, but this accessor returns host order.
pub fn get_identifier(&self) -> u16[src]
Get the identifier field. This field is always stored big-endian within the struct, but this accessor returns host order.
pub fn get_sequence_number(&self) -> u16[src]
Get the sequence_number field. This field is always stored big-endian within the struct, but this accessor returns host order.