Enum pnet::transport::TransportProtocol
[−]
[src]
pub enum TransportProtocol {
Ipv4(IpNextHeaderProtocol),
Ipv6(IpNextHeaderProtocol),
}Represents a transport layer protocol
Variants
Ipv4 | Represents a transport protocol built on top of IPv4 | |
Ipv6 | Represents a transport protocol built on top of IPv6 |